#
# spec file for package jupyter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define plainpython python
%define skip_python39 1
Name:           jupyter
Version:        1.0.0
Release:        13.3
Summary:        Metapackage to install all the Jupyter components in one go
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/jupyter
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter/jupyter-%{version}.tar.gz
Source1:        https://buildmedia.readthedocs.org/media/pdf/jupyter/latest/jupyter.pdf
Source2:        https://buildmedia.readthedocs.org/media/htmlzip/jupyter/latest/jupyter.zip
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module ipywidgets}
#BuildRequires:  %%{python_module jupyter-client}
BuildRequires:  %{python_module jupyter-core}
BuildRequires:  %{python_module jupyter_console}
BuildRequires:  %{python_module nbconvert}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module qtconsole}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-ipykernel
Requires:       python-ipywidgets
# current notebook 6.5 requires jupyter-client < 8
#Requires:       python-jupyter-client
Requires:       python-jupyter-core
Requires:       python-jupyter_console
Requires:       python-nbconvert
Requires:       python-notebook
Requires:       python-qtconsole
Requires:       %plainpython(abi) = %{python_version}
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       jupyter = %{version}-%{release}
Obsoletes:      jupyter < %{version}-%{release}
%endif
BuildArch:      noarch
%python_subpackages

%description
Jupyter is an environment for interactive computing in multiple languages.
It includes a console, a browser-based notebook format, and support for
dozens of languages through the use of language-specific kernels.

Jupyter is an evolution and modularization of the IPython project, separating
out the python3-specific parts from the language-agnostic parts.

This package pulls in the main Jupyter system, including the notebook,
qtconsole, and the IPython kernel.  Additional components and kernels
can be installed separately.

%package        -n jupyter-doc
Summary:        HTML documentation for %{name}
Group:          Development/Languages/Python
Provides:       %{name}-doc-html = %{version}-%{release}
Provides:       %{name}-doc-pdf = %{version}-%{release}
Provides:       %{python_module %{name}-doc = %{version}-%{release}}
Provides:       %{python_module %{name}-doc-html = %{version}-%{release}}
Provides:       %{python_module %{name}-doc-pdf = %{version}-%{release}}
Obsoletes:      %{name}-doc-html < %{version}-%{release}
Obsoletes:      %{name}-doc-pdf < %{version}-%{release}
Obsoletes:      %{python_module %{name}-doc-html < %{version}-%{release}}
Obsoletes:      %{python_module %{name}-doc-pdf < %{version}-%{release}}

%description    -n jupyter-doc
Documentation and help files for %{name}.

%prep
%setup -q -n jupyter-%{version}
unzip %{SOURCE2} -d docs
mv docs/jupyter-* docs/html
rm docs/html/.buildinfo

%build
%python_build

%install
%python_install

# Install documentation
mkdir -p %{buildroot}%{_docdir}/%{name}

cp %{SOURCE1} %{buildroot}%{_docdir}/%{name}/
cp -r docs/html %{buildroot}%{_docdir}/%{name}/

%fdupes %{buildroot}%{_docdir}/%{name}/

%files %python_files
%license LICENSE
%doc README.md
%{python_sitelib}/jupyter-%{version}*-info
# This is provided by jupyter_core now
%exclude %{python_sitelib}/jupyter.py*
%pycache_only %exclude %{python_sitelib}/__pycache__/

%files -n jupyter-doc
%license LICENSE
%doc README.md
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/html/
%{_docdir}/%{name}/jupyter.pdf

%changelog
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Mon May 22 2023 Jiri Srain <jsrain@suse.com>
- refresh also the jupyter.zip from upstream URL
* Mon May 22 2023 Jiri Srain <jsrain@suse.com>
- refresh the jupyter.pdf from upstream URL
* Fri May  5 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Thu Mar 30 2023 Ben Greiner <code@bnavigator.de>
- remove explicit jupyter-client dep in order ot avoid resolver
  conflicts with python-notebook
* Fri Jan  7 2022 Ben Greiner <code@bnavigator.de>
- Skip python2: There is no python2-qtconsole
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Require python(abi) in order to silence rpmlint
* Sun Jan 31 2021 Ben Greiner <code@bnavigator.de>
- Back to singlespec for multiple python flavors. The primary
  python3 flavor provides the "jupyter" package.
- Do what the description advertises and what upstream does:
  Require the specified packages
- Update documentation files: jupyter.pdf and jupyter.zip
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- jupyter_core has been renamed to jupyter-core
- jupyter_client has been renamed to jupyter-client
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match jupyter package naming guidelines.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Remove jupyter.py since it is now provided by python3-jupyter_core.
- Clean up documentation building.
* Thu Mar 16 2017 jmatejek@suse.com
- do not Recommend jupyter_nbconvert (which pulls in texlive)
* Wed Oct 21 2015 toddrme2178@gmail.com
- No longer provide or obsolete IPython.
  This is provided and obsoleted by python-jupyter_ipython.
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 28 2015 toddrme2178@gmail.com
- Fix provides again.
* Fri Aug 28 2015 toddrme2178@gmail.com
- Fix provides and obsoletes
* Fri Aug 28 2015 toddrme2178@gmail.com
- Initial version
